@@ -31,6 +31,7 @@
 #if defined(__APPLE__) && (MAC_OS_X_VERSION_MAX_ALLOWED <= MAC_OS_X_VERSION_10_4)
 #ifndef NSUInteger
 #define NSUInteger unsigned int
+#define NSUIntegerMax UINT_MAX
 #endif
 #endif
 
@@ -40,7 +41,7 @@
 typedef struct {
   unsigned int date;
   unsigned int flags;
-  unsigned int position;   // For mbox based cache files
+  long position;   // For mbox based cache files
   unsigned int size;
   unsigned int imap_uid;   // For IMAP
   char *filename;          // For maildir base cache files
